@@ -32,13 +32,19 @@ class Matcher(Preprocessor):
                split=0,
                database='',
                one_match=False,
-               output_df=False,
-               output_format=''):
+               output_df=True,
+               output_name='',
+               output_format='csv'):
 
     if type(query) == list:
       self.query = query
+      self.output_name = 'PEPMatch_results'
     else:
       self.query = [str(sequence.seq) for sequence in parse_fasta(query)]
+      if output_name:
+        self.output_name = output_name
+      else:
+        self.output_name = query.replace('.fasta', '') + '_to_' + proteome.split('/')[-1].split('.')[0]
 
     self.lengths = sorted(list(set([len(peptide) for peptide in self.query])))
     self.proteome = proteome
@@ -114,6 +120,7 @@ class Matcher(Preprocessor):
     all_matches_dict = {}
 
     for peptide in peptides:
+      print(peptide)
       if len(peptide) < self.split:
         continue
 
@@ -127,15 +134,15 @@ class Matcher(Preprocessor):
       hit_list = []
       if len(peptide) % self.split == 0:
         for i in range(0, len(kmers), self.split):
-          
+
           get_positions = 'SELECT position FROM "{kmer_table}" WHERE kmer = "{actual_kmer}"'.format(kmer_table = kmers_table_name, actual_kmer = kmers[i])
           c.execute(get_positions)
           positions_fetch = c.fetchall()
-          
+
           try:
             for hit in positions_fetch:
               hit_list.append(hit[0] - i)
-          
+
           except:
             continue
 
@@ -187,7 +194,7 @@ class Matcher(Preprocessor):
     # compile all matches into format used for benchmarking (comma separated)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', '', '', '', '', '', ''))
       for match in matches:
         # retrieve protein IDs from the other created table
         get_protein_data = 'SELECT * FROM "{names_table}" WHERE protein_number = "{protein_number}"'.format(
@@ -195,7 +202,7 @@ class Matcher(Preprocessor):
         c.execute(get_protein_data)
         protein_data = c.fetchall()
 
-        all_matches.append((peptide, 
+        all_matches.append((peptide,
                             peptide,
                             protein_data[0][1],
                             protein_data[0][2],
@@ -204,8 +211,8 @@ class Matcher(Preprocessor):
                             protein_data[0][5],
                             0,                     # 0 mismatches for exact matches
                             (match % 100000),
-                            (match % 100000) + len(peptide), 
-                            protein_data[0][6], 
+                            (match % 100000) + len(peptide),
+                            protein_data[0][6],
                             protein_data[0][7]))
 
     c.close()
@@ -246,6 +253,7 @@ class Matcher(Preprocessor):
       rev_kmer_dict = {i: k for k, v in kmer_dict.items() for i in v}
 
     for peptide in peptides:
+      print(peptide)
       # record matches in a set so as to not duplicate matches
       matches = set()
 
@@ -382,6 +390,7 @@ class Matcher(Preprocessor):
             continue
 
       all_matches_dict[peptide] = list(matches)
+      print(list(matches))
 
     all_matches = []
 
@@ -389,7 +398,7 @@ class Matcher(Preprocessor):
     # (peptide, matched peptide, protein matched in, index, # of mismatches)
     for peptide, matches in all_matches_dict.items():
       if matches == []:
-        all_matches.append((peptide, '', '', '', '', '', '', ''))
+        all_matches.append((peptide, '', '', '', '', '', '', '', '', '', '', '', ''))
       else:
         for match in matches:
           all_matches.append((
@@ -397,10 +406,15 @@ class Matcher(Preprocessor):
             match[0],
             names_dict[(match[2] - (match[2] % 100000)) // 100000][0],
             names_dict[(match[2] - (match[2] % 100000)) // 100000][1],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][2],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][3],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][4],
             match[1],
             [i+1 for i in range(len(peptide)) if peptide[i] != match[0][i]],
             match[2] % 100000,
-            (match[2] % 100000) + len(peptide)))
+            (match[2] % 100000) + len(peptide),
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][5],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][6],))
 
     return all_matches
 
@@ -495,7 +509,7 @@ class Matcher(Preprocessor):
         df = self.dataframe_exact_matches(all_matches)
       else:
         df = self.dataframe_mismatch_matches(all_matches)
-      
+
       if self.output_format == '':
         return df
       else:
@@ -507,7 +521,7 @@ class Matcher(Preprocessor):
     '''Return Pandas dataframe of the results.'''
     df = pd.DataFrame(all_matches,
                       columns=['Peptide Sequence',
-                               'Matched Peptide',
+                               'Matched Sequence',
                                'Taxon ID',
                                'Species',
                                'Gene',
@@ -518,7 +532,7 @@ class Matcher(Preprocessor):
                                'Index end',
                                'Protein Existence Level',
                                'Gene Priority'])
-    
+
     if self.one_match:
       if df['Protein Existence Level'].isnull().values.any():
         df.drop_duplicates(['Peptide Sequence'], inplace=True)
@@ -535,19 +549,19 @@ class Matcher(Preprocessor):
       else:
         idx = df.groupby(['Peptide Sequence'])['Gene Priority'].transform('max') == df['Gene Priority']
         df = df[idx]
-      
+
       df.drop_duplicates(['Peptide Sequence'], inplace=True)
 
     # drop any columns that are entirely empty (usually gene priority column)
     df.dropna(how='all', axis=1, inplace=True)
 
-    return df 
+    return df
 
   def dataframe_mismatch_matches(self, all_matches):
     '''Return Pandas dataframe of the results.'''
     df = pd.DataFrame(all_matches,
                       columns=['Peptide Sequence',
-                               'Matched Peptide',
+                               'Matched Sequence',
                                'Taxon ID',
                                'Species',
                                'Gene',
@@ -566,16 +580,16 @@ class Matcher(Preprocessor):
     # drop any columns that are entirely empty (usually gene priority column)
     df.dropna(how='all', axis=1, inplace=True)
 
-    return df 
+    return df
 
   def output_matches(self, df):
     '''Write Pandas dataframe to format that is specified'''
-    results_id = ''.join(random.choice('0123456789ABCDEFabcdef') for i in range(6))
+    # results_id = ''.join(random.choice('0123456789ABCDEFabcdef') for i in range(6))
     if self.output_format == 'csv':
-      return df.to_csv('PEPMatch_results_' + results_id + '.csv')
+      return df.to_csv(self.output_name + '.csv')
     elif self.output_format == 'xlsx':
-      return df.to_excel('PEPMatch_results_' + results_id + '.xlsx')
+      return df.to_excel(self.output_name + '.xlsx')
     elif self.output_format == 'json':
-      return df.to_json('PEPMatch_results_' + results_id + '.json')
+      return df.to_json(self.output_name + '.json')
     elif self.output_format == 'html':
       return df.to_html()
\ No newline at end of file
